Skip to contents

A ~5,900-species sample of mammal trait records, prepared to mirror the structure of the TetrapodTraits 1.0.0 database. Used by the db-assembly-workflow_mammals vignette.

Usage

mammal_tetrapodtraits_example

Format

A tibble with ~5,911 rows and 3 columns:

Scientific.Name

Length-1 character vector. Scientific name (genus species), period-separated genus.species column name as in the source release.

BodyMass_g

Numeric. Body mass (g); NA when unknown.

LitterSize

Numeric. Mean litter size; NA when unknown.

Moura et al. (2024) A phylogeny-informed characterisation of global tetrapod traits addresses data gaps and biases. PLOS Biology 22:e3002658. doi:10.1371/journal.pbio.3002658