A crosswalk mapping species names between BirdLife International taxonomy
and the BirdTree (Jetz et al. 2012) taxonomy. This is useful as a
pre-built override table for reconciling datasets that use BirdLife names
against phylogenies that use BirdTree names. See
reconcile_crosswalk() to convert this into an overrides table.
Format
A data frame with ~11,000 rows and 4 columns:
- Species1
Species name in BirdLife taxonomy
- Species3
Species name in BirdTree taxonomy
- Match.type
Type of match:
"1BL to 1BT"(one-to-one),"Many BL to 1BT"(lump),"1BL to many BT"(split),"Extinct","Newly described species","Invalid taxon"- Match.notes
Additional notes on the match
The crosswalk is distributed as supporting information with the AVONET database release (Tobias et al. 2022). It maps two underlying taxonomies, both of which should be cited if you use the crosswalk in published work — see the references below.
References
Tobias, J.A. et al. (2022) AVONET: morphological, ecological and geographical data for all birds. Ecology Letters 25:581–597. doi:10.1111/ele.13898
Jetz, W., Thomas, G.H., Joy, J.B., Hartmann, K. & Mooers, A.O. (2012) The global diversity of birds in space and time. Nature 491:444–448. doi:10.1038/nature11631